@@ -135,7 +135,7 @@ class ParameterSweep(object):
         LUT[LUT != 0] = currentLvl
         self.ParametersLEDET.setAttribute(getattr(self.ParametersLEDET, 'Inputs'), 'I_PC_LUT', LUT)
 
-    def prepareSimulation(self, MagnetName, folder, cleanFolder = True,  OffsetNumber = 0, ROXIE_File = '', clean = False):
+    def prepareSimulation(self, MagnetName, folder, cleanFolder = False,  OffsetNumber = 0, ROXIE_File = ''):
         Adjust_vQ = 0
         if ROXIE_File:
             Adjust_vQ =1
@@ -147,10 +147,8 @@ class ParameterSweep(object):
         if cleanFolder:
             filelist = [f for f in os.listdir(folder)]
             for f in filelist:
-                if "selfMutualInductanceMatrix" in f:
-                    continue
-                if clean:
-                    os.remove(os.path.join(folder, f))
+                if "selfMutualInductanceMatrix" in f: continue
+                os.remove(os.path.join(folder, f))
         #2. Generate Permutations
         self.generatePermutations()
         #3. For loop for all Simulations
@@ -179,6 +177,10 @@ class ParameterSweep(object):
             if Adjust_vQ:
                 self.ParametersLEDET.adjust_vQ(ROXIE_File)
 
+            self.ParametersLEDET.Variables.variableToSaveTxt = np.append(self.ParametersLEDET.Variables.variableToSaveTxt, 'I_CoilSections')
+            self.ParametersLEDET.Variables.typeVariableToSaveTxt = np.append(self.ParametersLEDET.Variables.typeVariableToSaveTxt, 1)
+            self.ParametersLEDET.Options.flag_saveMatFile = 0
+            self.ParametersLEDET.Options.flag_generateReport = 0
             self.ParametersLEDET.writeFileLEDET(file_name)
 
         #4. Write CSV with all Parameters
