@@ -83,8 +83,7 @@ class QuenchPlanAnalysis():
         for c in col:
             colors = colors + [c]
         for c in col3:
-            if c == 'white': continue
-            if c == 'snow': continue
+            if c == 'white' or c == 'snow' or c == 'azure' or c == 'aliceblue': continue
             colors = colors + [c]
         for c in col2:
             if c == 'w': continue
@@ -235,7 +234,7 @@ class QuenchPlanAnalysis():
         return
 
     #############################################################################################################
-    ## Domain: Functions used by both SIMdata/TMDSdata domain
+    ## Domain: Functions used by both SIMdata/TMDSdata
     def __zero_runs(self, I, Itol = 10):
         if len(I.shape)<2: I = np.array([I]).transpose()
         I[abs(I) < Itol] = 0
@@ -363,7 +362,8 @@ class QuenchPlanAnalysis():
             ax.set_xlabel("x [mm]")
             ax.set_ylabel("y [mm]")
             ax.set_title("Turns to V-Taps")
-            ax.legend(legend)
+            # ax.legend(legend)
+            ax.legend(legend, loc='upper right')
         return
 
     def GetTDMSCoilStructure(self):
@@ -847,4 +847,5 @@ class QuenchPlanAnalysis():
         return
 
     def SaveToCSV(self):
+        # TODO
         return
